==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MapperTargetConnectionsInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A object which contains list of tables and connection details for a target connection.
 * @property connection Source connection details.
 * @property dataMapperMappings List of table mappings.
 * @property relationships List of relationship info among the tables.
 * @property targetEntities List of source tables for a target connection.
 */
public data class MapperTargetConnectionsInfoArgs(
    public val connection: Output<MapperConnectionArgs>? = null,
    public val dataMapperMappings: Output<List<DataMapperMappingArgs>>? = null,
    public val relationships: Output<List<Any>>? = null,
    public val targetEntities: Output<List<MapperTableArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs =
        com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs.builder()
            .connection(connection?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .dataMapperMappings(
                dataMapperMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .relationships(relationships?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .targetEntities(
                targetEntities?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [MapperTargetConnectionsInfoArgs].
 */
@PulumiTagMarker
public class MapperTargetConnectionsInfoArgsBuilder internal constructor() {
    private var connection: Output<MapperConnectionArgs>? = null

    private var dataMapperMappings: Output<List<DataMapperMappingArgs>>? = null

    private var relationships: Output<List<Any>>? = null

    private var targetEntities: Output<List<MapperTableArgs>>? = null

    /**
     * @param value Source connection details.
     */
    @JvmName("fbihbvygjrlbcdug")
    public suspend fun connection(`value`: Output<MapperConnectionArgs>) {
        this.connection = value
    }

    /**
     * @param value List of table mappings.
     */
    @JvmName("awatssddkhffrpjl")
    public suspend fun dataMapperMappings(`value`: Output<List<DataMapperMappingArgs>>) {
        this.dataMapperMappings = value
    }

    @JvmName("ghhteabnvjfhojmo")
    public suspend fun dataMapperMappings(vararg values: Output<DataMapperMappingArgs>) {
        this.dataMapperMappings = Output.all(values.asList())
    }

    /**
     * @param values List of table mappings.
     */
    @JvmName("csgiwmkxvifqlatw")
    public suspend fun dataMapperMappings(values: List<Output<DataMapperMappingArgs>>) {
        this.dataMapperMappings = Output.all(values)
    }

    /**
     * @param value List of relationship info among the tables.
     */
    @JvmName("fqbxanxnvmnpjasb")
    public suspend fun relationships(`value`: Output<List<Any>>) {
        this.relationships = value
    }

    @JvmName("hehqripgmagkmmgt")
    public suspend fun relationships(vararg values: Output<Any>) {
        this.relationships = Output.all(values.asList())
    }

    /**
     * @param values List of relationship info among the tables.
     */
    @JvmName("dyionuwasfimgtce")
    public suspend fun relationships(values: List<Output<Any>>) {
        this.relationships = Output.all(values)
    }

    /**
     * @param value List of source tables for a target connection.
     */
    @JvmName("vhsiagwejtcjjtrj")
    public suspend fun targetEntities(`value`: Output<List<MapperTableArgs>>) {
        this.targetEntities = value
    }

    @JvmName("enmiflxawfdgulbd")
    public suspend fun targetEntities(vararg values: Output<MapperTableArgs>) {
        this.targetEntities = Output.all(values.asList())
    }

    /**
     * @param values List of source tables for a target connection.
     */
    @JvmName("iwggblanpryiicet")
    public suspend fun targetEntities(values: List<Output<MapperTableArgs>>) {
        this.targetEntities = Output.all(values)
    }

    /**
     * @param value Source connection details.
     */
    @JvmName("ykitaxifrobegjbg")
    public suspend fun connection(`value`: MapperConnectionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connection = mapped
    }

    /**
     * @param argument Source connection details.
     */
    @JvmName("jxdkenterhytuayu")
    public suspend fun connection(argument: suspend MapperConnectionArgsBuilder.() -> Unit) {
        val toBeMapped = MapperConnectionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.connection = mapped
    }

    /**
     * @param value List of table mappings.
     */
    @JvmName("msbrcghhyebgpldr")
    public suspend fun dataMapperMappings(`value`: List<DataMapperMappingArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataMapperMappings = mapped
    }

    /**
     * @param argument List of table mappings.
     */
    @JvmName("tpcxaoogqgojtdto")
    public suspend
    fun dataMapperMappings(argument: List<suspend DataMapperMappingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataMapperMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataMapperMappings = mapped
    }

    /**
     * @param argument List of table mappings.
     */
    @JvmName("fcxfsosgrvnsbrho")
    public suspend fun dataMapperMappings(
        vararg
        argument: suspend DataMapperMappingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DataMapperMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataMapperMappings = mapped
    }

    /**
     * @param argument List of table mappings.
     */
    @JvmName("jhpkwtfaqlpmbfld")
    public suspend fun dataMapperMappings(argument: suspend DataMapperMappingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataMapperMappingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataMapperMappings = mapped
    }

    /**
     * @param values List of table mappings.
     */
    @JvmName("eanrhhecutoknvsl")
    public suspend fun dataMapperMappings(vararg values: DataMapperMappingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataMapperMappings = mapped
    }

    /**
     * @param value List of relationship info among the tables.
     */
    @JvmName("conpdromcrkbhmra")
    public suspend fun relationships(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.relationships = mapped
    }

    /**
     * @param values List of relationship info among the tables.
     */
    @JvmName("nwiaqlukyaqqrotc")
    public suspend fun relationships(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.relationships = mapped
    }

    /**
     * @param value List of source tables for a target connection.
     */
    @JvmName("abvjykjjtmxnccvq")
    public suspend fun targetEntities(`value`: List<MapperTableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetEntities = mapped
    }

    /**
     * @param argument List of source tables for a target connection.
     */
    @JvmName("qoysaifinnhethqr")
    public suspend fun targetEntities(argument: List<suspend MapperTableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { MapperTableArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.targetEntities = mapped
    }

    /**
     * @param argument List of source tables for a target connection.
     */
    @JvmName("onebklnuotsdxvej")
    public suspend fun targetEntities(vararg argument: suspend MapperTableArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { MapperTableArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.targetEntities = mapped
    }

    /**
     * @param argument List of source tables for a target connection.
     */
    @JvmName("jmuxxbnfagawexaf")
    public suspend fun targetEntities(argument: suspend MapperTableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MapperTableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.targetEntities = mapped
    }

    /**
     * @param values List of source tables for a target connection.
     */
    @JvmName("mtemjjpogxbhfode")
    public suspend fun targetEntities(vararg values: MapperTableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetEntities = mapped
    }

    internal fun build(): MapperTargetConnectionsInfoArgs = MapperTargetConnectionsInfoArgs(
        connection = connection,
        dataMapperMappings = dataMapperMappings,
        relationships = relationships,
        targetEntities = targetEntities,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MapperTargetConnectionsInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A object which contains list of tables and connection details for a target connection.
 * @property connection Source connection details.
 * @property dataMapperMappings List of table mappings.
 * @property relationships List of relationship info among the tables.
 * @property targetEntities List of source tables for a target connection.
 */
public data class MapperTargetConnectionsInfoArgs(
    public val connection: Output<MapperConnectionArgs>? = null,
    public val dataMapperMappings: Output<List<DataMapperMappingArgs>>? = null,
    public val relationships: Output<List<Any>>? = null,
    public val targetEntities: Output<List<MapperTableArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs =
        com.pulumi.azurenative.datafactory.inputs.MapperTargetConnectionsInfoArgs.builder()
            .connection(connection?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .dataMapperMappings(
                dataMapperMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .relationships(relationships?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .targetEntities(
                targetEntities?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [MapperTargetConnectionsInfoArgs].
 */
@PulumiTagMarker
public class MapperTargetConnectionsInfoArgsBuilder internal constructor() {
    private var connection: Output<MapperConnectionArgs>? = null

    private var dataMapperMappings: Output<List<DataMapperMappingArgs>>? = null

    private var relationships: Output<List<Any>>? = null

    private var targetEntities: Output<List<MapperTableArgs>>? = null

    /**
     * @param value Source connection details.
     */
    @JvmName("mmmtcwtkylfnqawi")
    public suspend fun connection(`value`: Output<MapperConnectionArgs>) {
        this.connection = value
    }

    /**
     * @param value List of table mappings.
     */
    @JvmName("ynqkotdrlusvtrld")
    public suspend fun dataMapperMappings(`value`: Output<List<DataMapperMappingArgs>>) {
        this.dataMapperMappings = value
    }

    @JvmName("onlqyjgvefmnoqdh")
    public suspend fun dataMapperMappings(vararg values: Output<DataMapperMappingArgs>) {
        this.dataMapperMappings = Output.all(values.asList())
    }

    /**
     * @param values List of table mappings.
     */
    @JvmName("ofwtdejkkmnrbdmb")
    public suspend fun dataMapperMappings(values: List<Output<DataMapperMappingArgs>>) {
        this.dataMapperMappings = Output.all(values)
    }

    /**
     * @param value List of relationship info among the tables.
     */
    @JvmName("xvqvkkwcoapeemka")
    public suspend fun relationships(`value`: Output<List<Any>>) {
        this.relationships = value
    }

    @JvmName("nrdxhcfpumcolfra")
    public suspend fun relationships(vararg values: Output<Any>) {
        this.relationships = Output.all(values.asList())
    }

    /**
     * @param values List of relationship info among the tables.
     */
    @JvmName("mudvaobyhsaullvr")
    public suspend fun relationships(values: List<Output<Any>>) {
        this.relationships = Output.all(values)
    }

    /**
     * @param value List of source tables for a target connection.
     */
    @JvmName("xqbmjnhlnrctneup")
    public suspend fun targetEntities(`value`: Output<List<MapperTableArgs>>) {
        this.targetEntities = value
    }

    @JvmName("rejemrmvguykoico")
    public suspend fun targetEntities(vararg values: Output<MapperTableArgs>) {
        this.targetEntities = Output.all(values.asList())
    }

    /**
     * @param values List of source tables for a target connection.
     */
    @JvmName("qydugjknibuvlfii")
    public suspend fun targetEntities(values: List<Output<MapperTableArgs>>) {
        this.targetEntities = Output.all(values)
    }

    /**
     * @param value Source connection details.
     */
    @JvmName("rxgksoivkwcybexv")
    public suspend fun connection(`value`: MapperConnectionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connection = mapped
    }

    /**
     * @param argument Source connection details.
     */
    @JvmName("eharxrswljraxfot")
    public suspend fun connection(argument: suspend MapperConnectionArgsBuilder.() -> Unit) {
        val toBeMapped = MapperConnectionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.connection = mapped
    }

    /**
     * @param value List of table mappings.
     */
    @JvmName("sertifylxqakgfcy")
    public suspend fun dataMapperMappings(`value`: List<DataMapperMappingArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataMapperMappings = mapped
    }

    /**
     * @param argument List of table mappings.
     */
    @JvmName("bbdvbneaudgbxtdj")
    public suspend
    fun dataMapperMappings(argument: List<suspend DataMapperMappingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataMapperMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataMapperMappings = mapped
    }

    /**
     * @param argument List of table mappings.
     */
    @JvmName("ybryyhhhjwevootm")
    public suspend fun dataMapperMappings(
        vararg
        argument: suspend DataMapperMappingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DataMapperMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataMapperMappings = mapped
    }

    /**
     * @param argument List of table mappings.
     */
    @JvmName("glfurcaatlrerjim")
    public suspend fun dataMapperMappings(argument: suspend DataMapperMappingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataMapperMappingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataMapperMappings = mapped
    }

    /**
     * @param values List of table mappings.
     */
    @JvmName("urkfiduojfsjwrds")
    public suspend fun dataMapperMappings(vararg values: DataMapperMappingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataMapperMappings = mapped
    }

    /**
     * @param value List of relationship info among the tables.
     */
    @JvmName("cdaqcpleocysjrmg")
    public suspend fun relationships(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.relationships = mapped
    }

    /**
     * @param values List of relationship info among the tables.
     */
    @JvmName("lmljnjatnyysqnsv")
    public suspend fun relationships(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.relationships = mapped
    }

    /**
     * @param value List of source tables for a target connection.
     */
    @JvmName("jldbguugwdhfnqjk")
    public suspend fun targetEntities(`value`: List<MapperTableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetEntities = mapped
    }

    /**
     * @param argument List of source tables for a target connection.
     */
    @JvmName("dxjfaqnetjakngcb")
    public suspend fun targetEntities(argument: List<suspend MapperTableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { MapperTableArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.targetEntities = mapped
    }

    /**
     * @param argument List of source tables for a target connection.
     */
    @JvmName("umtdorbwrlnbunyv")
    public suspend fun targetEntities(vararg argument: suspend MapperTableArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { MapperTableArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.targetEntities = mapped
    }

    /**
     * @param argument List of source tables for a target connection.
     */
    @JvmName("piqrjxyewrdeicvr")
    public suspend fun targetEntities(argument: suspend MapperTableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MapperTableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.targetEntities = mapped
    }

    /**
     * @param values List of source tables for a target connection.
     */
    @JvmName("vhqtehioshdveckw")
    public suspend fun targetEntities(vararg values: MapperTableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetEntities = mapped
    }

    internal fun build(): MapperTargetConnectionsInfoArgs = MapperTargetConnectionsInfoArgs(
        connection = connection,
        dataMapperMappings = dataMapperMappings,
        relationships = relationships,
        targetEntities = targetEntities,
    )
}
